@@ -3,7 +3,7 @@ from pbpstats.objects.game import Game
 from pbpstats.objects.season import Season
 
 __all__ = [
-    'Day',
-    'Game',
-    'Season',
+    "Day",
+    "Game",
+    "Season",
 ]
