@@ -1,7 +1,7 @@
+from pbpstats.resources.enhanced_pbp import Foul, JumpBall, Turnover
 from pbpstats.resources.enhanced_pbp.stats_nba.enhanced_pbp_item import (
     StatsEnhancedPbpItem,
 )
-from pbpstats.resources.enhanced_pbp import JumpBall, Turnover, Foul
 
 
 class StatsJumpBall(JumpBall, StatsEnhancedPbpItem):
